set can be 1) a vector or 2) a right-hand sided formula in
which variables are separated by '+'. In either case, it is tested
if the first two variables in the set are conditionally
independent given the remaining variables in set. (Notice
an abuse of the '+' operator in the right-hand sided formula: The
order of the variables does matter.)
If set is NULL then it is tested whether the first
two variables are conditionally independent given the remaining
variables.
x must be a list with components cov and n.obs
such as returned by calling cov.wt( , method='ML') on a
dataframe.